import {Platform, StyleSheet, View, ScrollView} from 'react-native';

import {Center, Heading, Text, Spinner, HStack} from 'native-base';
import {animated, useSpring} from '@react-spring/native';

import {SafeAreaView} from 'react-native-safe-area-context';

import {useSelector, useDispatch} from 'react-redux';
import {RootState, store} from '@caj/redux/store';

import imgSrc from '@caj/img/maimg.png';
import {placeholder} from '@caj/lang/default';
import {getBackgroundColor} from '@caj/configs/colors';
import {useEffect} from 'react';
import {initAppData} from '@caj/helper/appData';
import {appStatus} from '@caj/configs/appNonSaveVar';
import {appNonSaveVarActions} from '@caj/configs/appNonSaveVarReducer';

const AnimationView = animated(View);

function onAppStart() {
  initAppData().then(() => {
    console.log('finish');
    setTimeout(() => {
      store.dispatch(appNonSaveVarActions.setAppStatus(appStatus.APP_RUNNING));
    }, 500);
    //store.dispatch(actions.loadPreferences(appVar));
  });
}

function StartHelper() {
  const currentAppStatus = useSelector(
    (state: RootState) => state.nonSaveVariables.appStatus,
  );

  const lang = useSelector((state: RootState) => state.appVariables.lang);
  const theme = useSelector(
    (state: RootState) => state.appVariables.preferences.theme,
  );

  const [motionProps, api] = useSpring(
    () => ({
      from: {
        translateX: -150,
        width: 4,
        opacity: 1,
      },
    }),
    [],
  );

  useEffect(() => {
    api.start({
      to: [
        {
          translateX: 150,
          width: 4,
          opacity: 1,
        },
        {
          translateX: -150,
          width: 4,
          opacity: 1,
        },
      ],
      loop: true,
    });
  }, []);

  useEffect(onAppStart, []);

  if (currentAppStatus === appStatus.APP_RUNNING) return null;

  return (
    <SafeAreaView
      style={[{flex: 1, backgroundColor: getBackgroundColor(theme)}]}>
      <Center height={'100%'}>
        <AnimationView
          style={{
            height: 100,
            position: 'absolute',

            backgroundColor: '#f22',
            borderRadius: 8,

            width: motionProps.width,
            opacity: motionProps.opacity,
            transform: [{translateX: motionProps.translateX}, {translateY: 5}],
          }}
        />
        <Heading>{lang.appName}</Heading>

        <HStack mt="5" space={2} justifyContent="center">
          <Spinner color="#ff7d4f" accessibilityLabel="Loading posts" />
          <Heading color="#ff7d4f" fontSize="md">
            {lang.startHelper1}
          </Heading>
        </HStack>
      </Center>
    </SafeAreaView>
  );
}

export default StartHelper;
